# Streamlit Ace

[React Ace](https://github.com/securingsincity/react-ace) component for [Streamlit](https://www.streamlit.io/).

## Installation

In a python virtual environment, run:

```sh
pip install streamlit-ace
```

## Demo

To test this component, you can run the demo script:

```sh
streamlit run https://raw.githubusercontent.com/Ghasel/streamlit-ace/master/examples/streamlit_ace_demo.py
```
